@@ -110,9 +110,11 @@ def test_identity(klass, value):
 
 @pytest.mark.parametrize("klass", [Timestamp, Timedelta, Period])
 @pytest.mark.parametrize("value", ["", "nat", "NAT", None, np.nan])
-def test_equality(klass, value):
+def test_equality(klass, value, request):
     if klass is Period and value == "":
-        pytest.skip("Period cannot parse empty string")
+        request.node.add_marker(
+            pytest.mark.xfail(reason="Period cannot parse empty string")
+        )
 
     assert klass(value).value == iNaT
 
@@ -188,7 +190,7 @@ def test_nat_iso_format(get_nat):
 @pytest.mark.parametrize(
     "klass,expected",
     [
-        (Timestamp, ["freqstr", "normalize", "to_julian_date", "to_period", "tz"]),
+        (Timestamp, ["freqstr", "normalize", "to_julian_date", "to_period"]),
         (
             Timedelta,
             [
@@ -318,6 +320,7 @@ def test_overlap_public_nat_methods(klass, expected):
         _get_overlap_public_nat_methods(Timestamp, True)
         + _get_overlap_public_nat_methods(Timedelta, True)
     ),
+    ids=lambda x: f"{x[0].__name__}.{x[1]}",
 )
 def test_nat_doc_strings(compare):
     # see gh-17327
